@@ -9,23 +9,28 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 {
-  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.025';
+  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.027';
 }
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
 
+use v5.10;
+
 use Moose;
 use namespace::autoclean;
 use MooseX::AttributeShortcuts;
+use Moose::Util::TypeConstraints;
 
 use Dist::Zilla;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+use Config::MVP::Slicer 0.302;
 use Path::Class;
 
 use Dist::Zilla::PluginBundle::Git 1.121770         ( );
 use Dist::Zilla::PluginBundle::Git::CheckFor        ( );
 use Dist::Zilla::Plugin::ArchiveRelease             ( );
+use Dist::Zilla::Plugin::CheckChangesHasContent     ( );
 use Dist::Zilla::Plugin::CheckPrereqsIndexed        ( );
 use Dist::Zilla::Plugin::CopyFilesFromBuild         ( );
 use Dist::Zilla::Plugin::ConfirmRelease             ( );
@@ -61,8 +66,12 @@ use Dist::Zilla::Plugin::Test::Compile              ( );
 use Dist::Zilla::Plugin::Test::PodSpelling 2.002001 ( );
 use Dist::Zilla::Plugin::Test::Portability          ( );
 use Dist::Zilla::Plugin::TestRelease                ( );
+use Dist::Zilla::Plugin::Twitter                    ( );
 use Dist::Zilla::Plugin::UploadToCPAN               ( );
 
+# non-plugin / dist.ini deps
+use Dist::Zilla::Stash::PAUSE::Encrypted 0.003 ( );
+
 # additional deps
 use Archive::Tar::Wrapper   ( );
 use Test::NoSmartComments   ( );
@@ -71,21 +80,69 @@ use Test::Pod               ( );
 use Test::Pod::Content      ( );
 use Pod::Coverage::TrustPod ( );
 
-has is_task    => (is => 'lazy', isa => 'Bool');
+# debugging...
+#use Smart::Comments '###';
+
+#has is_task    => (is => 'lazy', isa => 'Bool');
 has is_app     => (is => 'lazy', isa => 'Bool');
 has is_private => (is => 'lazy', isa => 'Bool');
 has rapid_dev  => (is => 'lazy', isa => 'Bool');
 
-sub _build_is_task    { $_[0]->payload->{task}                             }
+#sub _build_is_task    { $_[0]->payload->{task}                             }
 sub _build_is_app     { $_[0]->payload->{cat_app} || $_[0]->payload->{app} }
 sub _build_is_private { $_[0]->payload->{private}                          }
 sub _build_rapid_dev  { $_[0]->payload->{rapid_dev}                        }
 
+my $_d = sub { my $key = shift; sub { shift->payload->{$key} } };
+
+has $_ => (is => 'lazy', isa => 'Bool')
+    for qw{ sign tweet github install_on_release };
+has "is_$_" => (is => 'lazy', isa => 'Bool', default => $_d->($_))
+    for qw{ task };
+
+#sub _build_is_task    { shift->payload->{task}                             }
+sub _build_sign               { shift->payload->{sign}               // 1 }
+sub _build_tweet              { shift->payload->{tweet}              // 0 }
+sub _build_github             { shift->payload->{github}             // 1 }
+sub _build_install_on_release { shift->payload->{install_on_release} // 1 }
+
+has _slicer => (
+    is      => 'lazy',
+    isa     => class_type('Config::MVP::Slicer'),
+    handles => {
+        _merge_cfg => 'merge',
+    },
+);
+
+sub _build__slicer { Config::MVP::Slicer->new({ config => shift->payload }) }
+
+# TODO handle options for bundles!
+
+#around add_plugins => sub {
+my $_merger = sub {
+    my ($orig, $self) = (shift, shift);
+
+    my $_n = sub { 'Dist::Zilla::Plugin::' . shift };
+
+    ### @_
+    my @plugins =
+        map { $self->_merge_cfg($_) }
+        map { @$_ == 2 ? [ $_->[0], $_n->($_->[0]), $_->[1] ] : $_ }
+        map { (!ref $_ && !blessed $_) ? [ $_, $_n->($_), {} ] : $_ }
+        @_;
+
+    ### @plugins
+    return $self->$orig(@plugins);
+};
+
+around add_plugins => $_merger;
+#around add_bundle  => $_merger;
+
 
 sub copy_from_build {
     my ($self) = @_;
 
-    my @copy= qw{ LICENSE };
+    my @copy = (qw{ LICENSE });
     push @copy, 'Makefile.PL'
         if $self->is_app;
 
@@ -94,19 +151,32 @@ sub copy_from_build {
 
 
 sub release_plugins {
+    my $self = shift @_;
 
-    return (
+    my @plugins = (
         qw{
             TestRelease
-            ConfirmRelease
-            UploadToCPAN
+            CheckChangesHasContent
             CheckPrereqsIndexed
+            ConfirmRelease
         },
-
-        [ 'GitHub::Update' => { metacpan  => 1          } ],
-        [ Signature        => { sign      => 'always'   } ],
-        [ ArchiveRelease   => { directory => 'releases' } ],
     );
+
+    push @plugins, [ 'GitHub::Update' => { metacpan  => 1 } ]
+        if $self->github;
+    push @plugins, 'UploadToCPAN'
+        unless $self->is_private;
+    push @plugins, [ Signature => { sign => 'always' } ]
+        if $self->sign;
+    push @plugins, [ Twitter => { hash_tags => '#perl #cpan' } ]
+        if $self->tweet;
+    push @plugins, [ InstallRelease => { install_command => 'cpanm .' } ]
+        if $self->install_on_release;
+
+    push @plugins,
+        [ ArchiveRelease   => { directory => 'releases' } ];
+
+    return @plugins;
 }
 
 
@@ -136,11 +206,16 @@ sub author_tests {
 sub meta_provider_plugins {
     my ($self) = @_;
 
-    return (
-        qw{ GitHub::Meta MetaConfig MetaJSON MetaYAML },
+    my @plugins = (
+        qw{ MetaConfig MetaJSON MetaYAML },
         [ MetaNoIndex => { directory => [ qw{ corpus t } ] } ],
         'MetaProvides::Package',
     );
+
+    push @plugins, 'GitHub::Meta'
+        if $self->github;
+
+    return @plugins;
 }
 
 
@@ -162,7 +237,7 @@ sub configure {
     $self->add_bundle(Git => {
         allow_dirty => [ qw{ .gitignore LICENSE dist.ini weaver.ini README.pod Changes } ],
         tag_format  => '%v',
-        signed      => 1,
+        signed      => $self->sign, # 1,
     });
 
     $self->add_plugins([ 'Git::NextVersion' =>
@@ -174,10 +249,9 @@ sub configure {
     $self->add_bundle('Git::CheckFor');
 
     $self->add_plugins(
+        [ GatherDir => { exclude_filename => [ 'LICENSE' ] } ],
         qw{
-            GatherDir
             PruneCruft
-            License
             ExecDir
             ShareDir
             MakeMaker
@@ -185,23 +259,17 @@ sub configure {
             Manifest
             SurgicalPkgVersion
             ReadmeFromPod
+            MinimumPerl
+            ReportVersions::Tiny
         },
         [ AutoPrereqs => $autoprereq_opts ],
         [ Prepender   => $prepender_opts  ],
 
         $self->author_tests,
-
-        qw{
-            MinimumPerl
-            ReportVersions::Tiny
-        },
-
         $self->meta_provider_plugins,
         $self->release_plugins,
 
-        ($self->is_task ? 'TaskWeaver' : $podweaver),
-
-        [ PruneFiles => { filenames => [ $self->copy_from_build ] } ],
+        'License',
         [ CopyFilesFromBuild => { copy => [ $self->copy_from_build ] } ],
 
         [ ReadmeAnyFromPod  => ReadmePodInRoot => {
@@ -210,9 +278,7 @@ sub configure {
             location => 'root',
         }],
 
-        [ InstallRelease => {
-            install_command => 'cpanm .',
-        }],
+        ($self->is_task ? 'TaskWeaver' : $podweaver),
     );
 
     return;
@@ -226,12 +292,14 @@ sub stopwords {
         ABEND
         RSRCHBOY
         RSRCHBOY's
+        gpg
         ini
         metaclass
         metaclasses
         parameterized
         parameterization
         subclasses
+        coderef
     };
 }
 
@@ -253,7 +321,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.025 of Dist::Zilla::PluginBundle::RSRCHBOY - released June 30, 2012 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.027 of Dist::Zilla::PluginBundle::RSRCHBOY - released August 26, 2012 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
@@ -292,6 +360,45 @@ A list of words our POD spell checker should ignore.
 
 =for Pod::Coverage configure
 
+=head1 OPTIONS
+
+=head2 sign (boolean; default: true)
+
+On release, use your gpg key to sign the version tag created (if you're using
+git) and also generate a SIGNATURE file.
+
+See also L<Dist::Zilla::Plugin::Signature>.
+
+=head2 tweet (boolean; default: false)
+
+If set to a true value, we'll use L<Dist::Zilla::Plugin::Twitter> to tweet
+when a release occurs.
+
+=head2 github (boolean; default: true)
+
+This enables various GitHub related plugins to update dist and GitHub metadata
+automatically.
+
+=head2 install_on_release (boolean; default: true)
+
+After a release, install the distribution locally. Our default install command
+is (from inside the built release directory):
+
+    cpanm .
+
+You can change this by setting the C<InstallRelease.install_command> option.
+
+=head1 BUNDLED PLUGIN OPTIONS
+
+It's possible to pass options to our bundled plugins directly:
+
+    ; format is Plugin::Name.option
+    [@RSRCHBOY]
+    GatherDir.exclude_filename = cpanfile
+
+For information on specific plugins and their options, you should refer to the
+plugin's documentation.
+
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
@@ -302,6 +409,10 @@ Please see those modules/websites for more information related to this module.
 
 L<Dist::Zilla::Role::PluginBundle::Easy>
 
+=item *
+
+L<Config::MVP::Slicer>
+
 =back
 
 =head1 SOURCE
